@@ -4,7 +4,7 @@ use strict;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.03';
+    $VERSION     = '0.04';
     @ISA         = qw(Exporter);
     #Give a hoot don't pollute, do not export more than needed by default
     @EXPORT      = qw(_strip);
@@ -380,8 +380,8 @@ sub _strip {
     $script_raw =~ s/\t/ /g;  # remove tabs 
     $script_raw =~ s/\(/ \( /g; #  add white-space around ( 
     $script_raw =~ s/\)/ \) /g; #  add white-space around )
-    $script_raw =~ s/\s+\[/ \[ /g; # add white-space around [ 
-    $script_raw =~ s/\]\s+/ \] /g; # add white-space around ]
+    #$script_raw =~ s/\s+\[/ \[ /g; # add white-space around [ 
+    #$script_raw =~ s/\]\s+/ \] /g; # add white-space around ]
     $script_raw =~ s/\]\s*,/\],/g; # add white-space around ]
     $script_raw =~ s/"\s*,/", /g; # add white-space after , in list
     $script_raw =~ s/"\s+;/";/g; # remove white-space between " and ;
